# Monte Carlo Kernels (Paths)

This module contains JIT-compiled (`numba`) kernels for simulating the SDE paths of different financial models.

::: src.optpricing.techniques.kernels.american_mc_kernels
